/* This file is a component of the SurfAgent Proxy, based on original code from
 * the Internet Junkbuster Proxy.
 *
 * Copyright (C) 2000 Gabriel L. Somlo
 * Copyright (C) 1997 Anonymous Coders and Junkbusters Corporation
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program (see ../GPL.txt); if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

/*******************************   strlist.h   *********************************

    Purpose: Simple string list abstract data type module header

    Notes:   This module implements a straightforward string ordered list 
             abstract data type.  It is optimized for appending and deleting 
             from the end of the list.  Since they are ordered lists, string
             lists may be sorted, and their members are addressed by ordinal
             position (starting from 0).
**/


#ifndef STRLIST_H
#define STRLIST_H


#define NULL_INDEX                     -1        /* invalid string index */


typedef struct _StrListStruct *StrList;          /* the base string list type */


extern int     StrListAppend( StrList list, const char *string );
extern int     StrListRemove( StrList list, int idx );
extern int     StrListDequeue( StrList list );
extern int     StrListPop( StrList list );
extern int     StrListAppendFile( StrList list, char *filename );
extern StrList StrListCreate( void );
extern StrList StrListDup( StrList list );
extern void    StrListDestroy( StrList list );
extern int     StrListEqual( StrList list1, StrList list2 );
extern char *  StrListPeek( StrList list, int index );
extern int     StrListSize( StrList list );
extern void    StrListSort( StrList list );
extern void    StrListUnique( StrList list );
extern int     StrListFind( StrList list, char *string );
extern int     StrListSave( const StrList list, const char *filename );


#endif  /* STRLIST_H */
