/* This file is a component of the SurfAgent Proxy, based on original code from
 * the Internet Junkbuster Proxy.
 *
 * Copyright (C) 2000 Gabriel L. Somlo
 * Copyright (C) 1997 Anonymous Coders and Junkbusters Corporation
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program (see ../GPL.txt); if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

/**********************************  trie.h  ***********************************

    Purpose: Interface to trie building functions.

    Notes:   None.
**/

#ifndef TRIE_H
#define TRIE_H


#define NCHARS 256		/* Max. number of ASCII characters dealt with */

#define TRIE_INS_INC 0		/* when inserting a string, increment count */
#define TRIE_INS_SET 1		/* when inserting a string, set count */

typedef struct _TrieNode *TrieNode;


extern TrieNode MakeEmptyTrie( void );
extern int      TrieInsertStr( TrieNode tn, const char *str, int flg, int cnt );
extern TrieNode TrieLoad( char *filename, TrieNode tn );
extern int      TrieSave( TrieNode tn, char *filename );
extern TrieNode TrieDelete( TrieNode tn );
extern TrieNode TrieNextChar( TrieNode tn, char c );
extern int      TrieStringCount( TrieNode tn );

#endif /* TRIE_H */
