/* This file is a component of the SurfAgent Proxy, based on original code from
 * the Internet Junkbuster Proxy.
 *
 * Copyright (C) 2000 Gabriel L. Somlo
 * Copyright (C) 1997 Anonymous Coders and Junkbusters Corporation
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program (see ../GPL.txt); if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

/********************************* wordvec.h ***********************************

    Purpose: Word vector abstract data type module header

    Notes:   This module implements a word-vector with word
             counts. It is intended for frequent insertions and updates,
             and therefore the underlying structure is a list sorted
             alphabetically.
**/


#ifndef WORDVEC_H
#define WORDVEC_H


#define WV_NORMALIZE_OFF 0
#define WV_NORMALIZE_ON  1


/* word-count/tfidf pair */
typedef struct _WordListStruct {
  char *word;
  double count;			/* integer or tf-idf */
  struct _WordListStruct *next;
} WordListStruct, *WordList;

/* word vector */
typedef struct {
  WordList wordlist;
  double length;		/* length of the vector */
} WordVecStruct, *WordVec;


extern WordVec WordVecNew( void );
extern WordVec WordVecLoad( char *filename );
extern int     WordVecSave( WordVec wv, char *filename );
extern WordVec WordVecDelete( WordVec wv );
extern int     WordVecInsert( WordVec wv, char *word );
extern WordVec WordVecSumWtNrm( WordVec wv1, double wt1, int nrm1,
                                WordVec wv2, double wt2, int nrm2 );
extern double  WordVecSimilarity( WordVec wv1, WordVec wv2 );


#endif  /* WORDVEC_H */
